@@ -3,7 +3,7 @@
 #' @description \code{IF.ESratio} returns the data and plots the shape of either the IF or the IF TS for the Expected Shortfall Ratio.
 #'
 #' @param returns Returns data of the asset or portfolio. This can be a numeric or an xts object.
-#' @param evalShape Evaluation of the shape of the IF risk measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
+#' @param evalShape Evaluation of the shape of the IF risk or performance measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
 #' @param retVals Values used to evaluate the shape of the IF.
 #' @param nuisPars Nuisance parameters used for the evaluation of the shape of the IF (if no returns are provided).
 #' @param k Range parameter for the shape of the IF (the SD gets multiplied k times).
@@ -19,7 +19,10 @@
 #' @param eff Tuning parameter for the normal distribution efficiency for the "locScaleRob" robust data cleaning.
 #' @param ... Additional parameters.
 #'
-#' @return Influence function of ESratio
+#' @return Influence function of ESratio.
+#' 
+#' @details 
+#' For further details on the usage of the \code{nuisPars} argument, please refer to Section 3.1 for the \code{RPEIF} vignette.
 #'
 #' @author Anthony-Alexander Christidis, \email{anthony.christidis@stat.ubc.ca}
 #'
@@ -126,7 +129,7 @@ IF.ESratio <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars=NUL
     if(!is.list(nuisPars))
       stop("nuisPars must be a list.")
   
-  # Evaluation of nuisance parameters
+    # Evaluation of nuisance parameters
   if(is.null(nuisPars))
     nuisPars <- nuisParsFn() else{
       if(!is.null(nuisPars$mu)){
@@ -147,13 +150,25 @@ IF.ESratio <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars=NUL
       nuisPars <- nuisParsFn(nuis.mu, nuis.sd, nuis.c, nuis.alpha, nuis.beta)
     }
   
+  # Storing the dates
+  if(xts::is.xts(returns))
+    returns.dates <- zoo::index(returns)
+  
+  # Adding the robust filtering functionality
+  if(cleanOutliers){
+    temp.returns <- robust.cleaning(returns, cleanMethod, alpha.robust, eff)
+    if(xts::is.xts(returns))
+      returns <- xts::xts(temp.returns, returns.dates) else
+        returns <- temp.returns
+  }
+  
   # Function evaluation
   if(isTRUE(evalShape)){
     if(is.null(retVals))
       if(!is.null(returns))
         retVals <- seq(mean(returns)-k*sd(returns), mean(returns)+k*sd(returns), by=0.001) else
           retVals <- seq(0.005-k*0.07, 0.005+k*0.07, by=0.001)
-        IFvals <- cbind(retVals, IF.fn(retVals, risk="ESratio", returns, nuisPars , alpha, rf))
+        IFvals <- cbind(retVals, IF.fn(retVals, estimator="ESratio", returns, nuisPars , alpha, rf))
         colnames(IFvals) <- c("r", "IFvals")
         if(isTRUE(IFplot)){
           plot(IFvals[,1], IFvals[,2], type="l", 
@@ -169,19 +184,7 @@ IF.ESratio <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars=NUL
             stop() 
           }
   }
-  
-  # Storing the dates
-  if(xts::is.xts(returns))
-    returns.dates <- zoo::index(returns)
-  
-  # Adding the robust filtering functionality
-  if(cleanOutliers){
-    temp.returns <- robust.cleaning(returns, cleanMethod, alpha.robust, eff)
-    if(xts::is.xts(returns))
-      returns <- xts::xts(temp.returns, returns.dates) else
-        returns <- temp.returns
-  }
-  
+
   # Computing the mean of the returns
   mu.hat <- mean(returns)
   # Computing the SD of the returns
