@@ -3,7 +3,7 @@
 #' @description \code{IF.mean} returns the data and plots the shape of either the IF or the IF TS for the mean.
 #'
 #' @param returns Returns data of the asset or portfolio. This can be a numeric or an xts object.
-#' @param evalShape Evaluation of the shape of the IF risk measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
+#' @param evalShape Evaluation of the shape of the IF risk or performance measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
 #' @param retVals Values used to evaluate the shape of the IF.
 #' @param nuisPars Nuisance parameters used for the evaluation of the shape of the IF (if no returns are provided).
 #' @param k Range parameter for the shape of the IF (the SD gets multiplied k times).
@@ -17,7 +17,10 @@
 #' @param eff Tuning parameter for the normal distribution efficiency for the "locScaleRob" robust data cleaning.
 #' @param ... Additional parameters.
 #'
-#' @return Influence function for the specified risk measure.
+#' @return Influence function for the specified risk or performance measure.
+#' 
+#' @details 
+#' For further details on the usage of the \code{nuisPars} argument, please refer to Section 3.1 for the \code{RPEIF} vignette.
 #'
 #' @export
 #'
@@ -33,7 +36,7 @@
 #'                     "GM", "LS", "MA", "RV", "SS", "FoF") 
 #' 
 #' # Plot of IF a specified TS 
-#' outIF <- IF.mean(risk="mean",
+#' outIF <- IF.mean(estimator="mean",
 #'                  returns=edhec[,"CA"], evalShape=TRUE, 
 #'                  retVals=seq(-0.1, 0.1, by=0.001), nuisPars=NULL,
 #'                  IFplot=TRUE, IFprint=TRUE)
@@ -131,13 +134,25 @@ IF.mean <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars=NULL,
       nuisPars <- nuisParsFn(nuis.mu, nuis.sd, nuis.c, nuis.alpha, nuis.beta)
     }
   
+  # Storing the dates
+  if(xts::is.xts(returns))
+    returns.dates <- zoo::index(returns)
+  
+  # Adding the robust filtering functionality
+  if(cleanOutliers){
+    temp.returns <- robust.cleaning(returns, cleanMethod, alpha.robust, eff)
+    if(xts::is.xts(returns))
+      returns <- xts::xts(temp.returns, returns.dates) else
+        returns <- temp.returns
+  }
+  
   # Function evaluation
   if(isTRUE(evalShape)){
     if(is.null(retVals))
       if(!is.null(returns))
         retVals <- seq(mean(returns)-k*sd(returns), mean(returns)+k*sd(returns), by=0.001) else
           retVals <- seq(nuisPars$mu-k*0.07, nuisPars$mu+k*0.07, by=0.001)
-        IFvals <- cbind(retVals, IF.fn(retVals, risk="mean", returns, nuisPars ))
+        IFvals <- cbind(retVals, IF.fn(retVals, estimator="mean", returns, nuisPars ))
         colnames(IFvals) <- c("r", "IFvals")
         if(isTRUE(IFplot)){
           plot(IFvals[,1], IFvals[,2], type="l", 
@@ -154,18 +169,6 @@ IF.mean <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars=NULL,
           }
   }
   
-  # Storing the dates
-  if(xts::is.xts(returns))
-    returns.dates <- zoo::index(returns)
-  
-  # Adding the robust filtering functionality
-  if(cleanOutliers){
-    temp.returns <- robust.cleaning(returns, cleanMethod, alpha.robust, eff)
-    if(xts::is.xts(returns))
-      returns <- xts::xts(temp.returns, returns.dates) else
-        returns <- temp.returns
-  }
-  
   # Computing the mean of the returns
   mu.hat <- mean(returns)
   
